DeviceSettingsPlatform class abstract

The interface that implementations of open_device_settings must implement.

Inheritance
  • Object
  • PlatformInterface
  • DeviceSettingsPlatform
Implementers

Constructors

DeviceSettingsPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported(SettingsPanel panel) Future<bool>
Returns true if panel is supported on the current platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openSettings(SettingsPanel panel, {String? packageName}) Future<bool>
Opens the given panel on the current platform. Returns true if the panel was opened successfully.
openSystemSettings() Future<bool>
Opens the system settings at the top level.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DeviceSettingsPlatform
getter/setter pair