MethodChannelOpenSettingsPanel class
Method channel implementation of DeviceSettingsPlatform.
- Inheritance
-
- Object
- PlatformInterface
- DeviceSettingsPlatform
- MethodChannelOpenSettingsPanel
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isSupported(
SettingsPanel panel) → Future< bool> -
Returns
trueifpanelis supported on the current platform.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openSettings(
SettingsPanel panel, {String? packageName}) → Future< bool> -
Opens the given
panelon the current platform. Returnstrueif the panel was opened successfully.override -
openSystemSettings(
) → Future< bool> -
Opens the system settings at the top level.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited